==> libuhd-docs-4.9.0.1-2-x86_64.pkg.tar.zst: usr/share/doc/uhd/doxygen/html/soft__register_8hpp.js <==
var soft__register_8hpp =
[
    [ "uhd::soft_register_base", "classuhd_1_1soft__register__base.html", "classuhd_1_1soft__register__base" ],
    [ "uhd::soft_register_t< reg_data_t, readable, writable >", "classuhd_1_1soft__register__t.html", "classuhd_1_1soft__register__t" ],
    [ "uhd::soft_register_sync_t< reg_data_t, readable, writable >", "classuhd_1_1soft__register__sync__t.html", "classuhd_1_1soft__register__sync__t" ],
    [ "uhd::soft_regmap_accessor_t", "classuhd_1_1soft__regmap__accessor__t.html", "classuhd_1_1soft__regmap__accessor__t" ],
    [ "uhd::soft_regmap_t", "classuhd_1_1soft__regmap__t.html", "classuhd_1_1soft__regmap__t" ],
    [ "uhd::soft_regmap_db_t", "classuhd_1_1soft__regmap__db__t.html", "classuhd_1_1soft__regmap__db__t" ],
    [ "UHD_DEFINE_SOFT_REG_FIELD", "soft__register_8hpp.html#a90948c954ccce196de880718aa843876", null ],
    [ "uhd::soft_reg32_ro_sync_t", "namespaceuhd.html#a177c31678c712acced8173ec404ad178", null ],
    [ "uhd::soft_reg32_ro_t", "namespaceuhd.html#a26cdfcc7c8077f1e46cf22fd42686bf3", null ],
    [ "uhd::soft_reg32_rw_sync_t", "namespaceuhd.html#a2b29a17b5d81aa4c837bdce36604d216", null ],
    [ "uhd::soft_reg32_rw_t", "namespaceuhd.html#a2713c13f3072e311ded9a42f7bbafc3a", null ],
    [ "uhd::soft_reg32_wo_sync_t", "namespaceuhd.html#acde92b4ca30b6504fb6a96b7f6c61e87", null ],
    [ "uhd::soft_reg32_wo_t", "namespaceuhd.html#aec1dacc012e2ba6f3b5d9bc0fa12fdba", null ],
    [ "uhd::soft_reg64_ro_sync_t", "namespaceuhd.html#a10bbd65b2e073c7aab4b68ad06409919", null ],
    [ "uhd::soft_reg64_ro_t", "namespaceuhd.html#a302ff6d870309d2427457b5eb86d42bd", null ],
    [ "uhd::soft_reg64_rw_sync_t", "namespaceuhd.html#aa3d5beba78098ab13c9a04645994e12c", null ],
    [ "uhd::soft_reg64_rw_t", "namespaceuhd.html#ae50db623231bbad7ddb6ee53137bdb6d", null ],
    [ "uhd::soft_reg64_wo_sync_t", "namespaceuhd.html#afe8fb35f779a9404633aa59b2bf2d569", null ],
    [ "uhd::soft_reg64_wo_t", "namespaceuhd.html#a0a51d59cd94438b1ce2e007835a7d945", null ],
    [ "uhd::soft_reg_field_t", "namespaceuhd.html#a26b715eb56721759ca7b040c035c2842", null ],
    [ "uhd::soft_reg_flush_mode_t", "namespaceuhd.html#ad780ee43a0ed61d03b7c217e1e7c3e21", [
      [ "uhd::OPTIMIZED_FLUSH", "namespaceuhd.html#ad780ee43a0ed61d03b7c217e1e7c3e21a74d5568c04bd90ae11f4bf02012a2e4a", null ],
      [ "uhd::ALWAYS_FLUSH", "namespaceuhd.html#ad780ee43a0ed61d03b7c217e1e7c3e21ae613792d0cb1e928c6cafd7f595f7ab4", null ]
    ] ],
    [ "uhd::likely", "namespaceuhd.html#a05c1925e6ba499c5855e20c5a5b6e352", null ],
    [ "uhd::soft_reg_field::mask", "namespaceuhd_1_1soft__reg__field.html#a07cf4a63f8c8b7dd4a81f3d796212f39", null ],
    [ "uhd::soft_reg_field::shift", "namespaceuhd_1_1soft__reg__field.html#a10e6b68c969d1a68e7fb6515b1060123", null ],
    [ "uhd::unlikely", "namespaceuhd.html#a13b304ec2c517bfba480c1f59ca180d0", null ],
    [ "uhd::soft_reg_field::width", "namespaceuhd_1_1soft__reg__field.html#af204ce6f004a1d780d7dff246a6dffbb", null ]
];

==> libuhd-docs-4.9.0.1-4-x86_64.pkg.tar.zst: usr/share/doc/uhd/doxygen/html/soft__register_8hpp.js <==
var soft__register_8hpp =
[
    [ "uhd::soft_register_base", "classuhd_1_1soft__register__base.html", "classuhd_1_1soft__register__base" ],
    [ "uhd::soft_register_t&lt; reg_data_t, readable, writable &gt;", "classuhd_1_1soft__register__t.html", "classuhd_1_1soft__register__t" ],
    [ "uhd::soft_register_sync_t&lt; reg_data_t, readable, writable &gt;", "classuhd_1_1soft__register__sync__t.html", "classuhd_1_1soft__register__sync__t" ],
    [ "uhd::soft_regmap_accessor_t", "classuhd_1_1soft__regmap__accessor__t.html", "classuhd_1_1soft__regmap__accessor__t" ],
    [ "uhd::soft_regmap_t", "classuhd_1_1soft__regmap__t.html", "classuhd_1_1soft__regmap__t" ],
    [ "uhd::soft_regmap_db_t", "classuhd_1_1soft__regmap__db__t.html", "classuhd_1_1soft__regmap__db__t" ],
    [ "UHD_DEFINE_SOFT_REG_FIELD", "soft__register_8hpp.html#a90948c954ccce196de880718aa843876", null ],
    [ "uhd::soft_reg32_ro_sync_t", "namespaceuhd.html#a177c31678c712acced8173ec404ad178", null ],
    [ "uhd::soft_reg32_ro_t", "namespaceuhd.html#a26cdfcc7c8077f1e46cf22fd42686bf3", null ],
    [ "uhd::soft_reg32_rw_sync_t", "namespaceuhd.html#a2b29a17b5d81aa4c837bdce36604d216", null ],
    [ "uhd::soft_reg32_rw_t", "namespaceuhd.html#a2713c13f3072e311ded9a42f7bbafc3a", null ],
    [ "uhd::soft_reg32_wo_sync_t", "namespaceuhd.html#acde92b4ca30b6504fb6a96b7f6c61e87", null ],
    [ "uhd::soft_reg32_wo_t", "namespaceuhd.html#aec1dacc012e2ba6f3b5d9bc0fa12fdba", null ],
    [ "uhd::soft_reg64_ro_sync_t", "namespaceuhd.html#a10bbd65b2e073c7aab4b68ad06409919", null ],
    [ "uhd::soft_reg64_ro_t", "namespaceuhd.html#a302ff6d870309d2427457b5eb86d42bd", null ],
    [ "uhd::soft_reg64_rw_sync_t", "namespaceuhd.html#aa3d5beba78098ab13c9a04645994e12c", null ],
    [ "uhd::soft_reg64_rw_t", "namespaceuhd.html#ae50db623231bbad7ddb6ee53137bdb6d", null ],
    [ "uhd::soft_reg64_wo_sync_t", "namespaceuhd.html#afe8fb35f779a9404633aa59b2bf2d569", null ],
    [ "uhd::soft_reg64_wo_t", "namespaceuhd.html#a0a51d59cd94438b1ce2e007835a7d945", null ],
    [ "uhd::soft_reg_field_t", "namespaceuhd.html#a26b715eb56721759ca7b040c035c2842", null ],
    [ "uhd::soft_reg_flush_mode_t", "namespaceuhd.html#ad780ee43a0ed61d03b7c217e1e7c3e21", [
      [ "uhd::OPTIMIZED_FLUSH", "namespaceuhd.html#ad780ee43a0ed61d03b7c217e1e7c3e21a74d5568c04bd90ae11f4bf02012a2e4a", null ],
      [ "uhd::ALWAYS_FLUSH", "namespaceuhd.html#ad780ee43a0ed61d03b7c217e1e7c3e21ae613792d0cb1e928c6cafd7f595f7ab4", null ]
    ] ],
    [ "uhd::likely", "namespaceuhd.html#a05c1925e6ba499c5855e20c5a5b6e352", null ],
    [ "uhd::soft_reg_field::mask", "namespaceuhd_1_1soft__reg__field.html#a07cf4a63f8c8b7dd4a81f3d796212f39", null ],
    [ "uhd::soft_reg_field::shift", "namespaceuhd_1_1soft__reg__field.html#a10e6b68c969d1a68e7fb6515b1060123", null ],
    [ "uhd::unlikely", "namespaceuhd.html#a13b304ec2c517bfba480c1f59ca180d0", null ],
    [ "uhd::soft_reg_field::width", "namespaceuhd_1_1soft__reg__field.html#af204ce6f004a1d780d7dff246a6dffbb", null ]
];
